decode_large_image

Function decode_large_image 

pub async fn decode_large_image(
    path: PathBuf,
    target_dimensions: Option<(u32, u32)>,
) -> Option<(PathBuf, u32, u32, Vec<u8>)>
Decode a large image asynchronously in a blocking thread pool.

This function is used for gallery mode where full-resolution images need to be loaded. It uses the full memory budget (GALLERY_MEMORY_LIMIT_MB) since only one image decodes at a time in gallery mode.